=== modified file 'command.py'
--- command.py	2009-11-07 16:59:01 +0000
+++ command.py	2010-02-25 04:15:25 +0000
@@ -4,6 +4,15 @@
 from version import version_info, __version__
 
 
+_testing = False
+# True if we are currently testing commands via the test suite.
+
+def _stop_testing():
+    """Set the _testing flag to indicate we are no longer testing."""
+    global _testing
+    _testing = False
+
+
 class BzrToolsCommand(commands.Command):
 
     def run_argv_aliases(self, argv, alias_argv=None):
@@ -21,6 +30,9 @@
     If version == bzrtools version + 1, assume compatible, with deprecations
     Otherwise, assume incompatible.
     """
+    global _testing
+    if _testing:
+        return
     desired_plus = (desired[0], desired[1]+1)
     bzrlib_version = bzrlib.version_info[:2]
     if bzrlib_version == desired or (bzrlib_version == desired_plus and

=== modified file 'tests/blackbox.py'
--- tests/blackbox.py	2009-11-11 07:34:28 +0000
+++ tests/blackbox.py	2010-02-25 04:15:18 +0000
@@ -6,9 +6,16 @@
 from bzrlib.config import LocationConfig
 from bzrlib.transport import get_transport
 from bzrlib.tests import TestCaseWithTransport, HardlinkFeature
+from bzrlib.plugins.bzrtools import command
 
 
 class TestBzrTools(TestCaseWithTransport):
+
+    def setUp(self):
+        TestCaseWithTransport.setUp(self)
+        command._testing = True
+        self.addCleanup(command._stop_testing)
+
     @staticmethod
     def touch(filename):
         file(filename, 'wb').write('')

=== modified file 'tests/shelf_tests.py'
--- tests/shelf_tests.py	2009-01-08 00:40:57 +0000
+++ tests/shelf_tests.py	2010-02-25 04:15:18 +0000
@@ -7,6 +7,7 @@
     UnshelveHunkSelector,
     )
 from bzrlib.plugins.bzrtools.errors import NoColor
+from bzrlib.plugins.bzrtools import command
 from bzrlib.plugins.bzrtools.command_classes import cmd_shelf1
 
 
@@ -32,6 +33,11 @@
 +hello test world
  
 """
+    def setUp(self):
+        bzrlib.tests.TestCaseWithTransport.setUp(self)
+        command._testing = True
+        self.addCleanup(command._stop_testing)
+
     def _check_diff(self, diff=DIFF_1, filename='test_file'):
         old_tree = self.tree.basis_tree()
         old_tree.lock_read()

=== modified file 'tests/test_link_tree.py'
--- tests/test_link_tree.py	2008-05-12 03:02:04 +0000
+++ tests/test_link_tree.py	2010-02-25 04:15:18 +0000
@@ -19,6 +19,7 @@
 from bzrlib.transform import TreeTransform
 from bzrlib.tests import TestCaseWithTransport, HardlinkFeature
 
+from bzrlib.plugins.bzrtools import command
 from bzrlib.plugins.bzrtools.link_tree import link_tree
 
 
@@ -73,9 +74,13 @@
 
     def test_link_tree(self):
         """Ensure the command works as intended"""
-        os.chdir('child')
-        self.parent_tree.unlock()
-        self.run_bzr('link-tree ../parent')
-        self.assertTrue(self.hardlinked())
-        # want teh addCleanup to work properly
-        self.parent_tree.lock_write()
+        command._testing = True
+        try:
+            os.chdir('child')
+            self.parent_tree.unlock()
+            self.run_bzr('link-tree ../parent')
+            self.assertTrue(self.hardlinked())
+            # want teh addCleanup to work properly
+            self.parent_tree.lock_write()
+        finally:
+            command._testing = False

